==> huaweicloudsdklive-3.1.73-py2.py3-none-any.whl: huaweicloudsdklive/v1/model/delay_config.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DelayConfig:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'app': 'str',
        'delay': 'int'
    }

    attribute_map = {
        'app': 'app',
        'delay': 'delay'
    }

    def __init__(self, app=None, delay=None):
        """DelayConfig

        The model defined in huaweicloud sdk

        :param app: 应用名，默认为live
        :type app: str
        :param delay: 延时时间，单位：ms。  包含如下取值： - 2000（低）。 - 4000（中）。 - 6000（高）。
        :type delay: int
        """
        
        

        self._app = None
        self._delay = None
        self.discriminator = None

        if app is not None:
            self.app = app
        if delay is not None:
            self.delay = delay

    @property
    def app(self):
        """Gets the app of this DelayConfig.

        应用名，默认为live

        :return: The app of this DelayConfig.
        :rtype: str
        """
        return self._app

    @app.setter
    def app(self, app):
        """Sets the app of this DelayConfig.

        应用名，默认为live

        :param app: The app of this DelayConfig.
        :type app: str
        """
        self._app = app

    @property
    def delay(self):
        """Gets the delay of this DelayConfig.

        延时时间，单位：ms。  包含如下取值： - 2000（低）。 - 4000（中）。 - 6000（高）。

        :return: The delay of this DelayConfig.
        :rtype: int
        """
        return self._delay

    @delay.setter
    def delay(self, delay):
        """Sets the delay of this DelayConfig.

        延时时间，单位：ms。  包含如下取值： - 2000（低）。 - 4000（中）。 - 6000（高）。

        :param delay: The delay of this DelayConfig.
        :type delay: int
        """
        self._delay = delay

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DelayConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdklive-3.1.155-py2.py3-none-any.whl: huaweicloudsdklive/v1/model/delay_config.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DelayConfig:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'app': 'str',
        'delay': 'int'
    }

    attribute_map = {
        'app': 'app',
        'delay': 'delay'
    }

    def __init__(self, app=None, delay=None):
        r"""DelayConfig

        The model defined in huaweicloud sdk

        :param app: 应用名，默认为live
        :type app: str
        :param delay: 延时时间，单位：ms。  包含如下取值： - 2000（低）。 - 4000（中）。 - 6000（高）。
        :type delay: int
        """
        
        

        self._app = None
        self._delay = None
        self.discriminator = None

        if app is not None:
            self.app = app
        if delay is not None:
            self.delay = delay

    @property
    def app(self):
        r"""Gets the app of this DelayConfig.

        应用名，默认为live

        :return: The app of this DelayConfig.
        :rtype: str
        """
        return self._app

    @app.setter
    def app(self, app):
        r"""Sets the app of this DelayConfig.

        应用名，默认为live

        :param app: The app of this DelayConfig.
        :type app: str
        """
        self._app = app

    @property
    def delay(self):
        r"""Gets the delay of this DelayConfig.

        延时时间，单位：ms。  包含如下取值： - 2000（低）。 - 4000（中）。 - 6000（高）。

        :return: The delay of this DelayConfig.
        :rtype: int
        """
        return self._delay

    @delay.setter
    def delay(self, delay):
        r"""Sets the delay of this DelayConfig.

        延时时间，单位：ms。  包含如下取值： - 2000（低）。 - 4000（中）。 - 6000（高）。

        :param delay: The delay of this DelayConfig.
        :type delay: int
        """
        self._delay = delay

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DelayConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
